[Bf-blender-cvs] [842f52d418a] master: Cleanup: Rename public "bUnit" functions

Hans Goudey noreply at git.blender.org
Wed Sep 9 15:41:28 CEST 2020


Commit: 842f52d418aaccae45c8e400eb0a8bddef0dbb51
Author: Hans Goudey
Date:   Wed Sep 9 08:41:15 2020 -0500
Branches: master
https://developer.blender.org/rB842f52d418aaccae45c8e400eb0a8bddef0dbb51

Cleanup: Rename public "bUnit" functions

This commit renames the functions in "BKE_unit.h` to be consistent
with the naming in the rest of blenkernel.

bUnit_AsString -> BKE_unit_value_as_string_adaptive
bUnit_AsString2 -> BKE_unit_value_as_string
bUnit_ReplaceString -> BKE_unit_replace_string
bUnit_ApplyPreferredUnit -> BKE_unit_apply_preferred_unit
bUnit_ToUnitAltName -> BKE_unit_name_to_alt
bUnit_ClosestScalar -> BKE_unit_closest_scalar
bUnit_BaseScalar -> BKE_unit_base_scalar
bUnit_IsValid -> BKE_unit_is_valid
bUnit_GetSystem -> BKE_unit_system_get
bUnit_GetBaseUnit -> BKE_unit_base_get
bUnit_GetBaseUnitOfType -> BKE_unit_base_of_type_get
bUnit_GetName -> BKE_unit_name_get
bUnit_GetNameDisplay -> BKE_unit_display_name_get
bUnit_GetIdentifier -> BKE_unit_identifier_get
bUnit_GetScaler -> BKE_unit_scalar_get
bUnit_IsSuppressed -> BKE_unit_is_suppressed

Differential Revision: https://developer.blender.org/D8828

===================================================================

M	source/blender/blenkernel/BKE_unit.h
M	source/blender/blenkernel/intern/scene.c
M	source/blender/blenkernel/intern/unit.c
M	source/blender/blenloader/intern/versioning_280.c
M	source/blender/draw/intern/draw_manager_text.c
M	source/blender/editors/interface/interface.c
M	source/blender/editors/interface/interface_eyedropper_depth.c
M	source/blender/editors/interface/interface_handlers.c
M	source/blender/editors/mesh/editmesh_bevel.c
M	source/blender/editors/space_view3d/view3d_draw.c
M	source/blender/editors/space_view3d/view3d_gizmo_ruler.c
M	source/blender/editors/transform/transform_mode_translate.c
M	source/blender/editors/util/numinput.c
M	source/blender/makesrna/intern/rna_scene.c
M	source/blender/python/intern/bpy_utils_units.c

===================================================================

diff --git a/source/blender/blenkernel/BKE_unit.h b/source/blender/blenkernel/BKE_unit.h
index d47cebb5dc8..c4af9ab40e2 100644
--- a/source/blender/blenkernel/BKE_unit.h
+++ b/source/blender/blenkernel/BKE_unit.h
@@ -29,49 +29,49 @@ struct UnitSettings;
 /* in all cases the value is assumed to be scaled by the user preference */
 
 /* humanly readable representation of a value in units (used for button drawing) */
-size_t bUnit_AsString(
+size_t BKE_unit_value_as_string_adaptive(
     char *str, int len_max, double value, int prec, int system, int type, bool split, bool pad);
-size_t bUnit_AsString2(char *str,
-                       int len_max,
-                       double value,
-                       int prec,
-                       int type,
-                       const struct UnitSettings *settings,
-                       bool pad);
+size_t BKE_unit_value_as_string(char *str,
+                                int len_max,
+                                double value,
+                                int prec,
+                                int type,
+                                const struct UnitSettings *settings,
+                                bool pad);
 
 /* replace units with values, used before python button evaluation */
-bool bUnit_ReplaceString(
+bool BKE_unit_replace_string(
     char *str, int len_max, const char *str_prev, double scale_pref, int system, int type);
 
 /* return true if the string contains any valid unit for the given type */
-bool bUnit_ContainsUnit(const char *str, int type);
+bool BKE_unit_string_contains_unit(const char *str, int type);
 
 /* If user does not specify a unit, this converts it to the unit from the settings. */
-double bUnit_ApplyPreferredUnit(const struct UnitSettings *settings, int type, double value);
+double BKE_unit_apply_preferred_unit(const struct UnitSettings *settings, int type, double value);
 
 /* make string keyboard-friendly: 10µm --> 10um */
-void bUnit_ToUnitAltName(char *str, int len_max, const char *orig_str, int system, int type);
+void BKE_unit_name_to_alt(char *str, int len_max, const char *orig_str, int system, int type);
 
 /* the size of the unit used for this value (used for calculating the ckickstep) */
-double bUnit_ClosestScalar(double value, int system, int type);
+double BKE_unit_closest_scalar(double value, int system, int type);
 
 /* base scale for these units */
-double bUnit_BaseScalar(int system, int type);
+double BKE_unit_base_scalar(int system, int type);
 
 /* return true is the unit system exists */
-bool bUnit_IsValid(int system, int type);
+bool BKE_unit_is_valid(int system, int type);
 
 /* loop over scales, could add names later */
 // double bUnit_Iter(void **unit, char **name, int system, int type);
 
-void bUnit_GetSystem(int system, int type, void const **r_usys_pt, int *r_len);
-int bUnit_GetBaseUnit(const void *usys_pt);
-int bUnit_GetBaseUnitOfType(int system, int type);
-const char *bUnit_GetName(const void *usys_pt, int index);
-const char *bUnit_GetNameDisplay(const void *usys_pt, int index);
-const char *bUnit_GetIdentifier(const void *usys_pt, int index);
-double bUnit_GetScaler(const void *usys_pt, int index);
-bool bUnit_IsSuppressed(const void *usys_pt, int index);
+void BKE_unit_system_get(int system, int type, const void **r_usys_pt, int *r_len);
+int BKE_unit_base_get(const void *usys_pt);
+int BKE_unit_base_of_type_get(int system, int type);
+const char *BKE_unit_name_get(const void *usys_pt, int index);
+const char *BKE_unit_display_name_get(const void *usys_pt, int index);
+const char *BKE_unit_identifier_get(const void *usys_pt, int index);
+double BKE_unit_scalar_get(const void *usys_pt, int index);
+bool BKE_unit_is_suppressed(const void *usys_pt, int index);
 
 /* aligned with PropertyUnit */
 enum {
diff --git a/source/blender/blenkernel/intern/scene.c b/source/blender/blenkernel/intern/scene.c
index a1f74dddbad..34af226ef72 100644
--- a/source/blender/blenkernel/intern/scene.c
+++ b/source/blender/blenkernel/intern/scene.c
@@ -154,11 +154,11 @@ static void scene_init_data(ID *id)
 
   scene->unit.system = USER_UNIT_METRIC;
   scene->unit.scale_length = 1.0f;
-  scene->unit.length_unit = (uchar)bUnit_GetBaseUnitOfType(USER_UNIT_METRIC, B_UNIT_LENGTH);
-  scene->unit.mass_unit = (uchar)bUnit_GetBaseUnitOfType(USER_UNIT_METRIC, B_UNIT_MASS);
-  scene->unit.time_unit = (uchar)bUnit_GetBaseUnitOfType(USER_UNIT_METRIC, B_UNIT_TIME);
-  scene->unit.temperature_unit = (uchar)bUnit_GetBaseUnitOfType(USER_UNIT_METRIC,
-                                                                B_UNIT_TEMPERATURE);
+  scene->unit.length_unit = (uchar)BKE_unit_base_of_type_get(USER_UNIT_METRIC, B_UNIT_LENGTH);
+  scene->unit.mass_unit = (uchar)BKE_unit_base_of_type_get(USER_UNIT_METRIC, B_UNIT_MASS);
+  scene->unit.time_unit = (uchar)BKE_unit_base_of_type_get(USER_UNIT_METRIC, B_UNIT_TIME);
+  scene->unit.temperature_unit = (uchar)BKE_unit_base_of_type_get(USER_UNIT_METRIC,
+                                                                  B_UNIT_TEMPERATURE);
 
   /* Anti-Aliasing threshold. */
   scene->grease_pencil_settings.smaa_threshold = 1.0f;
diff --git a/source/blender/blenkernel/intern/unit.c b/source/blender/blenkernel/intern/unit.c
index f4a280581f3..bfa031f0d64 100644
--- a/source/blender/blenkernel/intern/unit.c
+++ b/source/blender/blenkernel/intern/unit.c
@@ -662,7 +662,7 @@ static size_t unit_as_string_main(char *str,
   return unit_as_string(str, len_max, value, prec, usys, main_unit, pad ? ' ' : '\0');
 }
 
-size_t bUnit_AsString(
+size_t BKE_unit_value_as_string_adaptive(
     char *str, int len_max, double value, int prec, int system, int type, bool split, bool pad)
 {
   PreferredUnits units;
@@ -675,13 +675,13 @@ size_t bUnit_AsString(
   return unit_as_string_main(str, len_max, value, prec, type, split, pad, units);
 }
 
-size_t bUnit_AsString2(char *str,
-                       int len_max,
-                       double value,
-                       int prec,
-                       int type,
-                       const UnitSettings *settings,
-                       bool pad)
+size_t BKE_unit_value_as_string(char *str,
+                                int len_max,
+                                double value,
+                                int prec,
+                                int type,
+                                const UnitSettings *settings,
+                                bool pad)
 {
   bool do_split = (settings->flag & USER_UNIT_OPT_SPLIT) != 0;
   PreferredUnits units = preferred_units_from_UnitSettings(settings);
@@ -1059,7 +1059,7 @@ static const bUnitDef *unit_detect_from_str(const bUnitCollection *usys,
   return unit;
 }
 
-bool bUnit_ContainsUnit(const char *str, int type)
+bool BKE_unit_string_contains_unit(const char *str, int type)
 {
   for (int system = 0; system < UNIT_SYSTEM_TOT; system++) {
     const bUnitCollection *usys = unit_get_system(system, type);
@@ -1076,12 +1076,12 @@ bool bUnit_ContainsUnit(const char *str, int type)
   return false;
 }
 
-double bUnit_ApplyPreferredUnit(const struct UnitSettings *settings, int type, double value)
+double BKE_unit_apply_preferred_unit(const struct UnitSettings *settings, int type, double value)
 {
   PreferredUnits units = preferred_units_from_UnitSettings(settings);
   const bUnitDef *unit = get_preferred_display_unit_if_used(type, units);
 
-  const double scalar = (unit == NULL) ? bUnit_BaseScalar(units.system, type) : unit->scalar;
+  const double scalar = (unit == NULL) ? BKE_unit_base_scalar(units.system, type) : unit->scalar;
   const double bias = (unit == NULL) ? 0.0 : unit->bias; /* Base unit shouldn't have a bias. */
 
   return value * scalar + bias;
@@ -1103,7 +1103,7 @@ double bUnit_ApplyPreferredUnit(const struct UnitSettings *settings, int type, d
  *
  * \return True of a change was made.
  */
-bool bUnit_ReplaceString(
+bool BKE_unit_replace_string(
     char *str, int len_max, const char *str_prev, double scale_pref, int system, int type)
 {
   const bUnitCollection *usys = unit_get_system(system, type);
@@ -1133,7 +1133,7 @@ bool bUnit_ReplaceString(
   }
   else {
     /* BLI_snprintf would not fit into str_tmp, cant do much in this case.
      * Check for this because otherwise bUnit_ReplaceString could call its self forever. */
     return changed;
   }
 
@@ -1194,7 +1194,7 @@ bool bUnit_ReplaceString(
 }
 
 /* 45µm --> 45um */
-void bUnit_ToUnitAltName(char *str, int len_max, const char *orig_str, int system, int type)
+void BKE_unit_name_to_alt(char *str, int len_max, const char *orig_str, int system, int type)
 {
   const bUnitCollection *usys = unit_get_system(system, type);
 
@@ -1234,7 +1234,7 @@ void bUnit_ToUnitAltName(char *str, int len_max, const char *orig_str, int syste
   strncpy(str, orig_str, len_max);
 }
 
-double bUnit_ClosestScalar(double value, int system, int type)
+double BKE_unit_closest_scalar(double value, int system, int type)
 {
   const bUnitCollection *usys = unit_get_system(system, type);
 
@@ -1250,7 +1250,7 @@ double bUnit_ClosestScalar(double value, int system, int type)
   return unit->scalar;
 }
 
-double bUnit_BaseScalar(int system, int type)
+double BKE_unit_base_scalar(int system, int type)
 {
   const bUnitCollection *usys = unit_get_system(system, type);
   if (usys) {
@@ -1260,12 +1260,12 @@ double bUnit_BaseScalar(int system, int type)
   return 1.0;
 }
 
-bool bUnit_IsValid(int system, int type)
+bool BKE_unit_is_valid(int system, int type)
 {
   return !(system < 0 || system > UNIT_SYSTEM_TOT || type < 0 || type > B_UNIT_TYPE_TOT);
 }
 
-void bUnit_GetSystem(int system, int type, void const **r_usys_pt, int *r_len)
+void BKE_unit_system_get(int system, int type, void const **r_usys_pt, int *r_len)
 {
   const bUnitCollection *usys = unit_get_system(system, type);
   *r_usys_pt = usys;
@@ -1278,25 +1278,25 @@ void bUnit_GetSystem(int system, int type, void const **r_usys_pt, int *r_len)
   *r_len = usys->length;
 }
 
-int bUnit_GetBaseUnit(const void *usys_pt)
+int BKE_unit_base_get(const void *usys_pt)
 {
   return ((bUnitCollection *)usys_pt)->base_unit;
 }
 
-int 

@@ Diff output truncated at 10240 characters. @@
@@ -1133,7 +1133,7 @@ bool bUnit_ReplaceString(
   else {
     /* BLI_snprintf would not fit into str_tmp, cant do much in this case.
-     * Check for this because otherwise bUnit_ReplaceString could call its self forever. */
+     * Check for this because otherwise BKE_unit_replace_string could call its self forever. */
     return changed;
   }



More information about the Bf-blender-cvs mailing list